<!DOCTYPE kpartgui>
<kpartgui name="ark_kparts" version="7">
<ActionProperties>
    <Action name="select_all" icon="ark_selectall"/>
</ActionProperties>
<MenuBar>
 <Menu name="file"><text>&amp;File</text>
    <Action name="file_save_as"/>
 </Menu>
 <Menu name="edit"><text>&amp;Edit</text>
    <Action name="select"/>
    <Action name="select_all"/>
    <Action name="deselect_all"/>
    <Action name="invert_selection"/>
    <Separator lineSeparator="true"/>
    <Action name="shell_output"/>
 </Menu>
 <Menu name="action"><text>&amp;Action</text>
    <Action name="extract"/>
    <Action name="view"/>
    <Action name="open_with"/>
  </Menu>
 <Menu noMerge="1" name="settings">
    <text>&amp;Settings</text>
    <Merge name="StandardToolBarMenuHandler"/>
    <Action name="options_show_search_bar"/>
    <Separator/>
    <Action name="options_configure_keybinding" group="settings_configure"/>
    <Action name="options_configure_toolbars" group="settings_configure"/>
    <Action name="options_configure_ark" group="settings_configure"/>
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
  <Action name="extract"/>
  <Action name="view"/>
</ToolBar>
<Menu name="file_popup">
 <Action name="extract"/>
 <Action name="view"/>
 <Action name="open_with"/>
 <Separator lineSeparator="true"/>
 <Action name="select_all"/>
</Menu>
</kpartgui>
