<!DOCTYPE kpartgui>
<kpartgui version="2" name="kjots" >
 <MenuBar>

  <Menu name="file">
   <Action name="new_page" append="new_merge"/>
   <Action name="new_book" append="new_merge"/>
   <Separator/>
   <Action name="save_page_to" append="save_merge"/>
   <Action name="save_book_to" append="save_merge"/>
   <Separator/>
   <Action name="del_page" append="save_merge"/>
   <Action name="del_folder" append="save_merge"/>
  </Menu>

  <Menu name="edit">
   <Action name="copyIntoTitle" append="edit_paste_merge"/>
   <Action name="rename_entry"/>
   <Action name="insert_date"/>
  </Menu>

  <Action name="bookmarks"/>

  <Menu name="settings"></Menu>

  <Menu name="help"></Menu>
 </MenuBar>

 <ToolBar name="mainToolBar" fullWidth="true" >
  <Separator/>
  <Action name="insert_date"/>
 </ToolBar>
</kpartgui>
